==> funcs_aux-0.4.13.tar.gz: funcs_aux-0.4.13/README.md <==
![Ver/TestedPython](https://img.shields.io/pypi/pyversions/funcs_aux)
![Ver/Os](https://img.shields.io/badge/os_development-Windows-blue)  
![repo/Created](https://img.shields.io/github/created-at/centroid457/funcs_aux)
![Commit/Last](https://img.shields.io/github/last-commit/centroid457/funcs_aux)
![Tests/GitHubWorkflowStatus](https://github.com/centroid457/funcs_aux/actions/workflows/test_linux.yml/badge.svg)
![Tests/GitHubWorkflowStatus](https://github.com/centroid457/funcs_aux/actions/workflows/test_windows.yml/badge.svg)  
![repo/Size](https://img.shields.io/github/repo-size/centroid457/funcs_aux)
![Commit/Count/t](https://img.shields.io/github/commit-activity/t/centroid457/funcs_aux)
![Commit/Count/y](https://img.shields.io/github/commit-activity/y/centroid457/funcs_aux)
![Commit/Count/m](https://img.shields.io/github/commit-activity/m/centroid457/funcs_aux)

# funcs_aux (current v0.4.13/![Ver/Pypi Latest](https://img.shields.io/pypi/v/funcs_aux?label=pypi%20latest))

## DESCRIPTION_SHORT
useful funcs in one place

## DESCRIPTION_LONG
Now its just a beginning!
Designed to collect useful funcs in one place!


## Features
1. RESULTS:  
	- ResultValue - resolved ambiguity with None-result for any method result!  
	- ResultCum  
2. ITERABLES:  
	- work with any iterable data by path/...  
3. STRINGS:  
4. ValueWithUnit:  
	- work with multipliers  
	- work with positive/negative  
	- full comparing + arithmetics  
5. ValueFromVariant  
6. Valid  


********************************************************************************
## License
See the [LICENSE](LICENSE) file for license rights and limitations (MIT).


## Release history
See the [HISTORY.md](HISTORY.md) file for release history.


## Installation
```commandline
pip install funcs-aux
```


## Import
```python
from funcs_aux import *
```


********************************************************************************
## USAGE EXAMPLES
See tests, sourcecode and docstrings for other examples.  

********************************************************************************

==> funcs_aux-0.4.17.tar.gz: funcs_aux-0.4.17/README.md <==
![Ver/TestedPython](https://img.shields.io/pypi/pyversions/funcs_aux)
![Ver/Os](https://img.shields.io/badge/os_development-Windows-blue)  
![repo/Created](https://img.shields.io/github/created-at/centroid457/funcs_aux)
![Commit/Last](https://img.shields.io/github/last-commit/centroid457/funcs_aux)
![Tests/GitHubWorkflowStatus](https://github.com/centroid457/funcs_aux/actions/workflows/test_linux.yml/badge.svg)
![Tests/GitHubWorkflowStatus](https://github.com/centroid457/funcs_aux/actions/workflows/test_windows.yml/badge.svg)  
![repo/Size](https://img.shields.io/github/repo-size/centroid457/funcs_aux)
![Commit/Count/t](https://img.shields.io/github/commit-activity/t/centroid457/funcs_aux)
![Commit/Count/y](https://img.shields.io/github/commit-activity/y/centroid457/funcs_aux)
![Commit/Count/m](https://img.shields.io/github/commit-activity/m/centroid457/funcs_aux)

# funcs_aux (current v0.4.17/![Ver/Pypi Latest](https://img.shields.io/pypi/v/funcs_aux?label=pypi%20latest))

## DESCRIPTION_SHORT
useful funcs in one place

## DESCRIPTION_LONG
Now its just a beginning!
Designed to collect useful funcs in one place!


## Features
1. RESULTS:  
	- Explicit - resolved ambiguity with None-result for any method result!  
	- ResultCum  
2. ITERABLES:  
	- work with any iterable data by path/...  
3. STRINGS:  
4. ValueWithUnit:  
	- work with multipliers  
	- work with positive/negative  
	- full comparing + arithmetics  
5. ValueFromVariant  
6. Valid  


********************************************************************************
## License
See the [LICENSE](LICENSE) file for license rights and limitations (MIT).


## Release history
See the [HISTORY.md](HISTORY.md) file for release history.


## Installation
```commandline
pip install funcs-aux
```


## Import
```python
from funcs_aux import *
```


********************************************************************************
## USAGE EXAMPLES
See tests, sourcecode and docstrings for other examples.  

********************************************************************************
